@@ -828,11 +828,21 @@ class client():
 
     def register_sdf(self, file, userName, mappings, prefix=None, dry_run=False):
         files = self.upload_files([file])
+        if "files" not in files and len(files["files"]) != 1:
+            raise RuntimeError("Failed to upload file when trying to register SDF.")
+        else:
+            uploaded_file = files['files'][0]
+
         request = {
-            "fileName": files['files'][0]["name"],
+            "fileName": uploaded_file["name"],
             "userName": userName,
             "mappings": mappings,
         }
+
+        # If original name is returned from the fle upload service, pass it as part of the request so it is preserved by the server
+        if "originalName" in uploaded_file:
+            request["originalFileName"] = uploaded_file["originalName"]
+
         if prefix:
             request["labelPrefix"] = {
                 "name": prefix,
@@ -1288,7 +1298,7 @@ class client():
                                   first_itx_listings=[], second_itx_listings=[],
                                   codes_only=False,
                                   max_results=1000, combine_terms_with_and=False,
-                                  format='stub'):
+                                  format='stub', return_listings=None):
         """
         Query ACAS for deeply specified conditions
 
@@ -1306,6 +1316,50 @@ class client():
                 }
             combine_terms_with_and (bool): Whether to combine terms with 'and'
             format (str): ACAS format to fetch data in
+            return_listings (dict): Used when format = "flat". Return only the defined values or label listings and thing attributes in key value pair format. 
+                {
+                    "thingValues": [
+                        {
+                            # Code value return listing
+                            "key": return_status_key,
+                            "stateType": "metadata",
+                            "stateKind": "project metadata",
+                            "valueType": "codeValue",
+                            "valueKind": PROJECT_STATUS
+                        },
+                        {
+                            # String value return listing
+                            "key": return_description_key,
+                            "stateType": "metadata",
+                            "stateKind": "project metadata",
+                            "valueType": "stringValue",
+                            "valueKind": DESCRIPTION_KEY
+                        },
+                        {
+                            # Date value return listing
+                            "key": return_startdate_key,
+                            "stateType": "metadata",
+                            "stateKind": "project metadata",
+                            "valueType": "dateValue",
+                            "valueKind": START_DATE
+                        },
+                        {
+                            # Label return listing
+                            "key": return_name_key,
+                            "labelType": "name",
+                            "labelKind": PROJECT_NAME,
+                        },
+                        {
+                            # Numeric Value return listing
+                            "key": return_project_number_key,
+                            "stateType": "metadata",
+                            "stateKind": "project metadata",
+                            "valueType": "numericValue",
+                            "valueKind": PROJECT_NUMBER
+                        }
+                    ],
+                    "thingAttributes": ["codeName", "id", "modifiedDate"]
+                }
         Returns:
             if codes_only:
                 list of code_name strings
@@ -1323,7 +1377,9 @@ class client():
                 'firstInteractions': first_itx_listings,
                 'secondInteractions': second_itx_listings,
                 'combineTermsWithAnd': combine_terms_with_and,
-            }
+            },
+            'returnDTO': return_listings
+
         }
         params = {}
         if codes_only:
